@@ -505,10 +505,15 @@ class BaseExperiment:
         y_test_preds = self.model.predict(self.X_test)
         test_acc = (self.y_test==y_test_preds).astype(float).mean()
         y_train_predict_proba = self.model.predict_proba(self.X_train)
-        train_auc = roc_auc_score(y_true=self.y_train, y_score=y_train_predict_proba)
         y_val_predict_proba = self.model.predict_proba(self.X_val)
-        val_auc = roc_auc_score(y_true=self.y_val, y_score=y_val_predict_proba)
         y_test_predict_proba = self.model.predict_proba(self.X_test)
+        if self.n_classes==2:
+            y_train_predict_proba = y_train_predict_proba[:,1]
+            y_val_predict_proba = y_val_predict_proba[:,1]
+            y_test_predict_proba = y_test_predict_proba[:,1]
+
+        train_auc = roc_auc_score(y_true=self.y_train, y_score=y_train_predict_proba)
+        val_auc = roc_auc_score(y_true=self.y_val, y_score=y_val_predict_proba)   
         test_auc = roc_auc_score(y_true=self.y_test, y_score=y_test_predict_proba)
         self.logger.add_scalar('val/acc', val_acc)
         self.logger.add_scalar('train/acc', train_acc)
